# floative

[![style: effective dart](https://img.shields.io/badge/style-effective_dart-40c4ff.svg)](https://pub.dev/packages/effective_dart)

[![GitHub stars](https://img.shields.io/github/stars/floative/floative_flutter?style=social)](https://github.com/floative/floative_flutter)


## About this project

The floative package takes the name of my youtube channel (and not the other way around).

I started this project to help me create flutter apps more fast (way faster) then if I had to
create it from the ground.

It has features such as:

* Ship
  * Navigate without the need of the context anywhere in your app.
  * Show dialogs without context.
* Logger
  * Log your errors while you're developing your app in a prettier way.
* Factory
  * Register your instances in a singleton provider and get them anywhere
* Other cool features
  * dismiss your keyboard when you tap on the screen
  * choose a flavor for your app: prod, dev, test

## What is being developed as we speak?

- [ ] Internationalization
- [ ] State management
- [ ] lazy singletons in **Factory**
- [ ] async singletons in **Factory**
- [ ] tests

## How to use it?

#### Starting
Instead of using your normal **MaterialApp**, use the **FloativeMaterialApp**

```dart

  FloativeMaterialApp(
    home: HomePage(),
    flavor: Flavor.development    
  )
```
this will allow us to set everything up for you. 😊

#### Navigation - Or even better Ship 🤔

Things start to get cool here.
This module of the application was born because of my need to handle
screen navigation inside my view controller. I really didn't wan't to
give the controller the context as a dependency **imagine the tests**.
So I decided to implement a way that I wouldn't need the context anymore.
Ship was born.

##### Navigating

######  Go to another page
```dart
  Ship.I.to(page: MyPage());
```

That's it? Yep.

###### Get back to the previous page

```dart
  Ship.I.back();
```
or with some result:

```dart
   Ship.I.back(result: "my result");
```

######  Navigate to another page and replace the current one

```dart
  Ship.I.replace(page: MyNextPage());
```

###### Navigate back to a page (as far as you wan't)

```dart
  Ship.I.goBackTo(page: MyPage());
```

###### Start a page to get a result from it

```dart
  var result = await Ship.I.startPageForResult<String>(page: MyContentPage());
```

###### Want to show a dialog? Fear no more:

```dart
  Ship.I.showDialog(dialog: MyDialog());
```
close the dialog

```dart
  Ship.I.back(result: "My result");
```

Show the living pages:

```dart
  Ship.I.debugShowPages();
```


#### Factory - Singletons

To make tests easier and have a single managament instance for singletons,
I created the factory module.

It's really simple to use,
just add a singleton the factory:

```dart
  Floative.I.factory.register<MyInstanceType>(MyInstance());
```

and get it with:

```dart
  var myInstance = Floative.I.factory.get<MyInstanceType>();
```



#### That's it for now fellows. I hope you enjoy it.
Pull requests are welcome with tests.